Learn R Programming

keggorthology (version 2.22.0)

getKOprobes: obtain probe set IDs associated with a KO term

Description

obtain probe set IDs associated with a KO term

Usage

getKOprobes(str, useAcc=TRUE, plat="hgu95av2", na.action=na.omit)

Arguments

str
string giving a KEGG orthology term
useAcc
logical -- use all accessible terms?
plat
platform corresponding to a bioconductor annotation package, e.g., hgu95av2.db
na.action
function for dealing with NA

Value

character vector, typically processed by na.omit

Details

Based on keggorthology read of KEGG orthology, March 2 2010. Specifically, we run wget on ftp://ftp.genome.jp/pub/kegg/brite/ko/ko00001.keg and use parsing and modeling code given in inst/keggHTML to generate a data frame respecting the hierarchy, and then keggDF2graph to construct the graph.

Looks up the requested term and gives back the unique probe set ids on the platform.

Examples

Run this code
getKOtags("insulin")
es =  acc(KOgraph, "Endocrine System")
nm = names(es[[1]])
nm
esp = lapply(nm, getKOprobes)
names(esp) = nm
sapply(esp, length)

Run the code above in your browser using DataLab