Learn R Programming

keggorthology (version 2.20.0)

indRender: indented textual rendering of nodes of a hierarchical graph

Description

indented textual rendering of nodes of a hierarchical graph

Usage

indRender(klike, from=nodes(klike)[1], indent=" ")

Arguments

klike
a graph, with tree structure similar to KOgraph
from
a node name from which the rendering should proceed to all leaves
indent
token to use for indentation -- will be replicated to depth of node to be rendered to its left

Value

NULL

Details

Based on keggorthology read of KEGG orthology, March 2 2010. Specifically, we run wget on ftp://ftp.genome.jp/pub/kegg/brite/ko/ko00001.keg and use parsing and modeling code given in inst/keggHTML to generate a data frame respecting the hierarchy, and then keggDF2graph to construct the graph.

Examples

Run this code
data(KOgraph)
indRender(KOgraph, "Human Diseases")

Run the code above in your browser using DataLab